@@ -21,31 +21,32 @@
 
 """Utilities to make logging consistent and easy in :mod:`slimta` packages."""
 
-from __future__ import absolute_import, unicode_literals
+from __future__ import absolute_import
 
 import threading
-threading._DummyThread._Thread__stop = lambda x: 42
 
 import sys
 import traceback
 import re
-from six.moves import reprlib
 import logging
 from ast import literal_eval
 
+from slimta.util.pycompat import reprlib
 from .socket import SocketLogger
 from .subprocess import SubprocessLogger
 from .queuestorage import QueueStorageLogger
 from .http import HttpLogger
 
 __all__ = ['getSocketLogger', 'getSubprocessLogger', 'getQueueStorageLogger',
-           'getHttpLogger', 'log_exception']
+           'getHttpLogger', 'log_exception', 'parseline']
+
+threading._DummyThread._Thread__stop = lambda x: 42
 
 
 def getSocketLogger(name):
     """Wraps the result of :py:func:`logging.getLogger()` in a
-    :class:`SocketLogger` object to provide limited and consistent logging
-    output for socket operations.
+    :class:`~slimta.logging.socket.SocketLogger` object to provide limited and
+    consistent logging output for socket operations.
 
     :param name: ``name`` as passed in to :py:func:`logging.getLogger()`.
     :rtype: :class:`~slimta.logging.socket.SocketLogger`
@@ -57,7 +58,8 @@ def getSocketLogger(name):
 
 def getSubprocessLogger(name):
     """Wraps the result of :py:func:`logging.getLogger()` in a
-    :class:`SubprocessLogger` object to provide limited and consistent
+    :class:`~slimta.logging.subprocess.SubprocessLogger` object to provide
+    limited and consistent
     logging output for subprocess operations.
 
     :param name: ``name`` as passed in to :py:func:`logging.getLogger()`.
@@ -70,8 +72,8 @@ def getSubprocessLogger(name):
 
 def getQueueStorageLogger(name):
     """Wraps the result of :py:func:`logging.getLogger()` in a
-    :class:`QueueStorageLogger` object to provide limited and consistent
-    logging output for |QueueStorage| operations.
+    :class:`~slimta.logging.queuestorage.QueueStorageLogger` object to provide
+    limited and consistent logging output for |QueueStorage| operations.
 
     :param name: ``name`` as passed in to :py:func:`logging.getLogger()`.
     :rtype: :class:`~slimta.logging.queuestorage.QueueStorageLogger`
@@ -83,8 +85,9 @@ def getQueueStorageLogger(name):
 
 def getHttpLogger(name):
     """Wraps the result of :py:func:`logging.getLogger()` in a
-    :class:`HttpLogger` object to provide limited and consistent logging output
-    for WSGI-style requests and responses and other HTTP-related logs.
+    :class:`~slimta.logging.http.HttpLogger` object to provide limited and
+    consistent logging output for WSGI-style requests and responses and other
+    HTTP-related logs.
 
     :param name: ``name`` as passed in to :py:func:`logging.getLogger()`.
     :rtype: :class:`~slimta.logging.http.HttpLogger`
@@ -107,16 +110,17 @@ def log_exception(name, **kwargs):
     type, value, tb = sys.exc_info()
     if not value:
         return
-    exc_repr = reprlib.Repr()
-    exc_repr.maxstring = 1000
+    tb_repr = reprlib.Repr()
+    tb_repr.maxstring = 10000
     logger = logging.getLogger(name)
     data = kwargs.copy()
     data['message'] = str(value)
-    data['traceback'] = traceback.format_exception(type, value, tb)
     data['args'] = value.args
-    data_str = ' '.join(['='.join((key, exc_repr.repr(val)))
+    tb_str = traceback.format_exception(type, value, tb)
+    data_str = ' '.join(['='.join((key, log_repr.repr(val)))
                          for key, val in sorted(data.items())])
-    logger.error('exception:{0}:unhandled {1}'.format(type.__name__, data_str))
+    logger.error('exception:{0}:unhandled {1} traceback={2}'.format(
+        type.__name__, data_str, tb_repr.repr(tb_str)))
 
 
 log_repr = reprlib.Repr()
@@ -132,7 +136,7 @@ def logline(log, type, typeid, operation, **data):
         log('{0}:{1}:{2} {3}'.format(type, typeid, operation, data_str))
 
 
-parseline_pattern = re.compile(r'^([^:]+):([^:]+):(\S+) ?(.*)$')
+parseline_pattern = re.compile(r'^([^:]+):([^:]+):(\S+) ?')
 data_item_pattern = re.compile('^([^=]+)=')
 
 
@@ -160,10 +164,23 @@ def _parseline_data(remaining, data):
 
 
 def parseline(line):
+    """Given a log line generated from :mod:`slimta.logging`, return a
+    four-tuple of the following:
+
+    #. The log type -- e.g. ``'socket'``
+    #. The log ID based on type -- e.g. a file descriptor or PID
+    #. The log operation -- e.g. ``'connect'`` or ``'popen'``
+    #. The log data, a dictionary of relevant information
+
+    :param line: The log line to parse, with or without new-line characters.
+    :raises: ValueError
+
+    """
     match = parseline_pattern.match(line)
     if not match:
         raise ValueError(line)
-    type, id, op, data_str = match.groups()
+    type, id, op = match.groups()
+    data_str = line[match.end(0):]
     return type, id, op, _parseline_data(data_str, {})
 
 
