@@ -123,7 +123,7 @@ class TestEdgeSmtp(unittest.TestCase, MoxTestBase):
         client_sock = create_connection(server.server.address)
         client = Client(client_sock)
         client.get_banner()
-        client.ehlo(b'there')
+        client.ehlo('there')
         client.mailfrom('sender@example.com')
         client.rcptto('rcpt@example.com')
         client.data()
